/* eslint-disable react-hooks/exhaustive-deps */
'use client';

import { useState, useEffect } from 'react';
import ProtectedRoute from '@/components/ProtectedRoute';
import { PlusCircle, Edit, Trash2, ChevronLeft, ChevronRight } from 'lucide-react';
import SalarieModal from '@/components/admin/SalarieModal';
import DeleteConfirmation from '@/components/admin/DeleteConfirmation';
import { SearchBar } from '@/components/SearchBar';
import { 
  fetchSalaries, 
  fetchSites, 
  fetchServices,
  fetchSalariesBySite,
  fetchSalariesByService
} from '@/utils/api';
import { Salarie } from '@/types/Salarie';
import { Site } from '@/types/Site';
import { Service } from '@/types/Service';
import { PaginatedResponse } from '@/types/PaginatedResponse';

export default function SalariesManagement() {
  const [salaries, setSalaries] = useState<Salarie[]>([]);
  const [sites, setSites] = useState<Site[]>([]);
  const [services, setServices] = useState<Service[]>([]);
  
  const [currentPage, setCurrentPage] = useState(1);
  const [pageSize] = useState(10);
  const [totalItems, setTotalItems] = useState(0);
  const [totalPages, setTotalPages] = useState(0);
  
  const [searchTerm, setSearchTerm] = useState('');
  const [selectedSite, setSelectedSite] = useState<number | null>(null);
  const [selectedService, setSelectedService] = useState<number | null>(null);
  
  const [isLoading, setIsLoading] = useState(true);
  const [isModalOpen, setIsModalOpen] = useState(false);
  const [isDeleteModalOpen, setIsDeleteModalOpen] = useState(false);
  const [currentSalarie, setCurrentSalarie] = useState<Salarie | null>(null);
  const [error, setError] = useState<string | null>(null);


  useEffect(() => {
    loadData();
  }, [currentPage, pageSize, searchTerm, selectedSite, selectedService]);

  const loadData = async () => {
    setIsLoading(true);
    setError(null);
    
    try {
      // chargement des sites et des services qui se fait seulement au premier chargement
      if (sites.length === 0) {
        const sitesResponse = await fetchSites(1, 100);
        setSites(sitesResponse?.data || []);
      }
      
      if (services.length === 0) {
        const servicesResponse = await fetchServices(1, 100);
        setServices(servicesResponse?.data || []);
      }
      
      let salariesResponse: PaginatedResponse<Salarie>;
      
      if (selectedSite !== null) {
        salariesResponse = await fetchSalariesBySite(selectedSite, currentPage, pageSize);
      } else if (selectedService !== null) {
        salariesResponse = await fetchSalariesByService(selectedService, currentPage, pageSize);
      } else if (searchTerm) {
        salariesResponse = await fetchSalaries(currentPage, pageSize, searchTerm);
      } else {
        salariesResponse = await fetchSalaries(currentPage, pageSize);
      }
      
      setSalaries(salariesResponse?.data || []);
      setTotalItems(salariesResponse?.totalCount || 0);
      setTotalPages(salariesResponse?.totalPages || 0);
    } catch (error) {
      console.error('Erreur lors du chargement des données:', error);
      setError('Impossible de charger les données. Veuillez réessayer.');
      setSalaries([]);
      if (sites.length === 0) setSites([]);
      if (services.length === 0) setServices([]);
    } finally {
      setIsLoading(false);
    }
  };

  const handleOpenModal = (salarie: Salarie | null = null) => {
    setCurrentSalarie(salarie);
    setIsModalOpen(true);
  };

  const handleCloseModal = () => {
    setIsModalOpen(false);
    setCurrentSalarie(null);
  };

  const handleOpenDeleteModal = (salarie: Salarie) => {
    setCurrentSalarie(salarie);
    setIsDeleteModalOpen(true);
  };

  const handleCloseDeleteModal = () => {
    setIsDeleteModalOpen(false);
    setCurrentSalarie(null);
  };

  const handleSaveSalarie = async (salarie: Omit<Salarie, 'id'>) => {
    try {
      let response;
      
      if (currentSalarie) {
        response = await fetch('/api/salaries', {
          method: 'PUT',
          headers: { 'Content-Type': 'application/json' },
          body: JSON.stringify({
            ...salarie,
            id: currentSalarie.id
          }),
        });
      } else {
        response = await fetch('/api/salaries', {
          method: 'POST',
          headers: { 'Content-Type': 'application/json' },
          body: JSON.stringify(salarie),
        });
      }
      
      if (!response.ok) {
        const errorData = await response.json();
        throw new Error(errorData.message || "Erreur lors de l'opération");
      }
      
      handleCloseModal();
      loadData();
    } catch (error) {
      console.error(`Erreur lors de la création d'un salarié`, error);
      setError(`Erreur lors de la création d'un salarié`);
    }
  };
  
  const handleDeleteSalarie = async () => {
    if (!currentSalarie) return;
    
    try {

      
      // le routeur ne fonctionne pas correctement pour delete.. donc je gruge comme je peux
      const response = await fetch('/api/salaries/delete', {
        method: 'POST',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify({ id: currentSalarie.id })
      });
      
      if (!response.ok) {
        const errorData = await response.json();
        throw new Error(errorData.message || "Erreur lors de la suppression");
      }
      
      handleCloseDeleteModal();
      loadData();
    } catch (error) {
      console.error('Une erreur est survenue lors de la suppression du salarié :', error);
      setError('Une erreur est survenue lors de la suppression du salarié');
    }
  };

  
  // gestion de la pagination
  const handlePageChange = (newPage: number) => {
    if (newPage > 0 && newPage <= totalPages) {
      setCurrentPage(newPage);
    }
  };

  const handleSearch = (query: string) => {
    setSearchTerm(query);
    setCurrentPage(1);
  };

  const handleResetFilters = () => {
    setSearchTerm('');
    setSelectedSite(null);
    setSelectedService(null);
    setCurrentPage(1);
  };

  const handleSiteChange = (e: React.ChangeEvent<HTMLSelectElement>) => {
    const value = e.target.value ? parseInt(e.target.value) : null;
    setSelectedSite(value);
    setSelectedService(null);
    setCurrentPage(1);
  };

  const handleServiceChange = (e: React.ChangeEvent<HTMLSelectElement>) => {
    const value = e.target.value ? parseInt(e.target.value) : null;
    setSelectedService(value);
    setSelectedSite(null);
    setCurrentPage(1);
  };

  return (
    <ProtectedRoute>
      <div className="container mx-auto px-4 py-8">
        <div className="flex justify-between items-center mb-6">
          <h1 className="text-2xl font-bold">Gestion des Salariés</h1>
          <button
            onClick={() => handleOpenModal()}
            className="flex items-center gap-2 px-4 py-2 bg-primary text-white rounded-md hover:bg-primary-dark transition-colors"
          >
            <PlusCircle size={18} />
            <span>Ajouter un salarié</span>
          </button>
        </div>
        
        {/* filtre et recherche */}
        <div className="grid grid-cols-1 md:grid-cols-3 gap-4 mb-6">
          <SearchBar 
            onSearch={handleSearch} 
            placeholder="Rechercher un salarié..."
            initialValue={searchTerm}
          />
          
          <select
            value={selectedSite?.toString() || ''}
            onChange={handleSiteChange}
            className="px-3 py-2 border border-border rounded-md focus:outline-none focus:ring-2 focus:ring-primary"
          >
            <option value="">Tous les sites</option>
            {sites && sites.map((site) => (
              <option key={site.id} value={site.id}>{site.ville}</option>
            ))}
          </select>
          
          <select
            value={selectedService?.toString() || ''}
            onChange={handleServiceChange}
            className="px-3 py-2 border border-border rounded-md focus:outline-none focus:ring-2 focus:ring-primary"
          >
            <option value="">Tous les services</option>
            {services && services.map((service) => (
              <option key={service.id} value={service.id}>{service.nom}</option>
            ))}
          </select>
        </div>
        
        {/* boouton de réinitialisation des filtres */}
        {(searchTerm || selectedSite || selectedService) && (
          <div className="mb-4">
            <button
              onClick={handleResetFilters}
              className="text-primary hover:text-primary-dark text-sm font-medium flex items-center"
            >
              Réinitialiser les filtres
            </button>
          </div>
        )}

        {error && (
          <div className="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded mb-4">
            {error}
          </div>
        )}

        {isLoading ? (
          <div className="flex justify-center p-8">
            <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-primary"></div>
          </div>
        ) : (
          <div className="bg-card rounded-lg border border-border shadow-sm overflow-hidden">
            <div className="overflow-x-auto">
              <table className="w-full">
                <thead className="bg-muted">
                  <tr>
                    <th className="px-4 py-3 text-left text-sm font-medium">Nom</th>
                    <th className="px-4 py-3 text-left text-sm font-medium">Prénom</th>
                    <th className="px-4 py-3 text-left text-sm font-medium">Service</th>
                    <th className="px-4 py-3 text-left text-sm font-medium">Site</th>
                    <th className="px-4 py-3 text-left text-sm font-medium">Email</th>
                    <th className="px-4 py-3 text-right text-sm font-medium w-24">Actions</th>
                  </tr>
                </thead>
                <tbody className="divide-y divide-border">
                  {!salaries || salaries.length === 0 ? (
                    <tr>
                      <td colSpan={6} className="px-4 py-4 text-center text-muted-foreground">
                        Aucun salarié trouvé
                      </td>
                    </tr>
                  ) : (
                    salaries.map((salarie) => {
                      return (
                        <tr key={salarie.id} className="hover:bg-muted/50">
                          <td className="px-4 py-4">{salarie.nom}</td>
                          <td className="px-4 py-4">{salarie.prenom}</td>
                          <td className="px-4 py-4">{salarie.service?.nom || '-'}</td>
                          <td className="px-4 py-4">{salarie.site?.ville || '-'}</td>
                          <td className="px-4 py-4">{salarie.email}</td>
                          <td className="px-4 py-4 text-right">
                            <div className="flex justify-end gap-2">
                              <button
                                onClick={() => handleOpenModal(salarie)}
                                className="text-blue-600 hover:text-blue-800"
                                aria-label="Modifier"
                              >
                                <Edit size={18} />
                              </button>
                              <button
                                onClick={() => handleOpenDeleteModal(salarie)}
                                className="text-red-600 hover:text-red-800"
                                aria-label="Supprimer"
                              >
                                <Trash2 size={18} />
                              </button>
                            </div>
                          </td>
                        </tr>
                      );
                    })
                  )}
                </tbody>
              </table>
            </div>
            
            {/* pagination */}
            {totalPages > 1 && (
              <div className="flex justify-between items-center px-4 py-3 border-t border-border bg-muted">
                <div className="text-sm text-muted-foreground">
                  Affichage de <span className="font-medium">{((currentPage - 1) * pageSize) + 1}</span> à{' '}
                  <span className="font-medium">{Math.min(currentPage * pageSize, totalItems)}</span> sur{' '}
                  <span className="font-medium">{totalItems}</span> résultats
                </div>
                <div className="flex items-center gap-2">
                  <button
                    onClick={() => handlePageChange(currentPage - 1)}
                    disabled={currentPage <= 1}
                    className="p-2 rounded-md hover:bg-background disabled:opacity-50 disabled:pointer-events-none"
                  >
                    <ChevronLeft size={18} />
                  </button>
                  <span className="text-sm font-medium">
                    Page {currentPage} sur {totalPages}
                  </span>
                  <button
                    onClick={() => handlePageChange(currentPage + 1)}
                    disabled={currentPage >= totalPages}
                    className="p-2 rounded-md hover:bg-background disabled:opacity-50 disabled:pointer-events-none"
                  >
                    <ChevronRight size={18} />
                  </button>
                </div>
              </div>
            )}
          </div>
        )}
      </div>

      {/* modal d'ajout/modification */}
      {isModalOpen && sites && services && (
        <SalarieModal
          salarie={currentSalarie}
          services={services}
          sites={sites}
          onClose={handleCloseModal}
          onSave={handleSaveSalarie}
        />
      )}
      {/* modal pour confirmer la suppression */}
      {isDeleteModalOpen && currentSalarie && (
        <DeleteConfirmation
          title="Suppression d'un salarié"
          message={`Voulez vous vraiment supprimer ce salarié : ${currentSalarie.prenom} ${currentSalarie.nom} ?`}
          onConfirm={handleDeleteSalarie}
          onCancel={handleCloseDeleteModal}
        />
      )}
    </ProtectedRoute>
  );
}