'use client';

import { useState, useEffect } from 'react';
import ProtectedRoute from '@/components/ProtectedRoute';
import { PlusCircle, Edit, Trash2 } from 'lucide-react';
import ServiceModal from '@/components/admin/ServiceModal';
import DeleteConfirmation from '@/components/admin/DeleteConfirmation';

interface Service {
  id: number;
  nom: string;
}

export default function ServicesManagement() {
  const [services, setServices] = useState<Service[]>([]);
  const [isLoading, setIsLoading] = useState(true);
  const [isModalOpen, setIsModalOpen] = useState(false);
  const [isDeleteModalOpen, setIsDeleteModalOpen] = useState(false);
  const [currentService, setCurrentService] = useState<Service | null>(null);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    fetchServices();
  }, []);

  const fetchServices = async () => {
    setIsLoading(true);
    try {
      const response = await fetch('/api/services');
      if (!response.ok) throw new Error('Erreur lors du chargement des services');
      const data = await response.json();
      setServices(data.data);
    } catch (error) {
      setError('Impossible de charger les services. Veuillez réessayer.');
      console.error(error);
    } finally {
      setIsLoading(false);
    }
  };

  const handleOpenModal = (service: Service | null = null) => {
    setCurrentService(service);
    setIsModalOpen(true);
  };

  const handleCloseModal = () => {
    setIsModalOpen(false);
    setCurrentService(null);
  };

  const handleOpenDeleteModal = (service: Service) => {
    setCurrentService(service);
    setIsDeleteModalOpen(true);
  };

  const handleCloseDeleteModal = () => {
    setIsDeleteModalOpen(false);
    setCurrentService(null);
  };

  const handleSaveService = async (service: { nom: string }) => {
    try {
      if (currentService) {
        const response = await fetch(`/api/services/`, {
          method: 'PUT',
          headers: { 'Content-Type': 'application/json' },
          body: JSON.stringify({id: currentService.id,nom: service.nom}),
        });
        
        if (!response.ok) throw new Error("Erreur lors de la mise à jour");
      } else {
        const response = await fetch('/api/services', {
          method: 'POST',
          headers: { 'Content-Type': 'application/json' },
          body: JSON.stringify(service),
        });
        
        if (!response.ok) throw new Error("Erreur lors de la création");
      }
      
      handleCloseModal();
      fetchServices();
    } catch (error) {
      console.error(`Une erreur est survenue lors de l'enristrement des informations`, error);
      setError(`Une erreur est survenue lors de l'enregistrement du service`);
    }
  };

  const handleDeleteService = async () => {
    if (!currentService) return;
    
    try {
      const response = await fetch('/api/services/delete', {
        method: 'POST',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify({ id: currentService.id })
      });
      
      
      if (!response.ok) throw new Error("Erreur lors de la suppression");
      
      handleCloseDeleteModal();
      fetchServices();
    } catch (error) {
      console.log(error);
      
      console.error('Erreur lors de la suppression :', error);
      setError('Erreur lors de la suppression :');
    }
  };

  return (
    <ProtectedRoute>
      <div className="container mx-auto px-4 py-8">
        <div className="flex justify-between items-center mb-6">
          <h1 className="text-2xl font-bold">Gestion des Services</h1>
          <button
            onClick={() => handleOpenModal()}
            className="flex items-center gap-2 px-4 py-2 bg-primary text-white rounded-md hover:bg-primary-dark transition-colors"
          >
            <PlusCircle size={18} />
            <span>Ajouter un service</span>
          </button>
        </div>

        {error && (
          <div className="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded mb-4">
            {error}
          </div>
        )}

        {isLoading ? (
          <div className="flex justify-center p-8">
            <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-primary"></div>
          </div>
        ) : (
          <div className="bg-card rounded-lg border border-border shadow-sm overflow-x-auto">
            <table className="w-full">
              <thead className="bg-muted">
                <tr>
                  <th className="px-6 py-3 text-left text-sm font-medium">Service</th>
                  <th className="px-6 py-3 text-right text-sm font-medium w-24">Actions</th>
                </tr>
              </thead>
              <tbody className="divide-y divide-border">
                {services.length === 0 ? (
                  <tr>
                    <td colSpan={2} className="px-6 py-4 text-center text-muted-foreground">
                      Aucun service trouvé
                    </td>
                  </tr>
                ) : (
                  services.map((service) => (
                    <tr key={service.id} className="hover:bg-muted/50">
                      <td className="px-6 py-4">{service.nom}</td>
                      <td className="px-6 py-4 text-right">
                        <div className="flex justify-end gap-2">
                          <button
                            onClick={() => handleOpenModal(service)}
                            className="text-blue-600 hover:text-blue-800"
                            aria-label="Modifier"
                          >
                            <Edit size={18} />
                          </button>
                          <button
                            onClick={() => handleOpenDeleteModal(service)}
                            className="text-red-600 hover:text-red-800"
                            aria-label="Supprimer"
                          >
                            <Trash2 size={18} />
                          </button>
                        </div>
                      </td>
                    </tr>
                  ))
                )}
              </tbody>
            </table>
          </div>
        )}
      </div>

      {/* modal d'ajout/modification */}
      {isModalOpen && (
        <ServiceModal
          service={currentService}
          onClose={handleCloseModal}
          onSave={handleSaveService}
        />
      )}

      {/* modal de confirmation de suppression */}
      {isDeleteModalOpen && currentService && (
        <DeleteConfirmation
          title="Supprimer le service"
          message={`Êtes-vous sûr de vouloir supprimer le service "${currentService.nom}" ?`}
          onConfirm={handleDeleteService}
          onCancel={handleCloseDeleteModal}
        />
      )}
    </ProtectedRoute>
  );
}