'use client';

import { useState, useEffect } from 'react';
import ProtectedRoute from '@/components/ProtectedRoute';
import { PlusCircle, Edit, Trash2 } from 'lucide-react';
import SiteModal from '@/components/admin/SiteModal';
import DeleteConfirmation from '@/components/admin/DeleteConfirmation';

interface Site {
  id: number;
  ville: string;
  salaries?: unknown[];
}

interface PaginatedResponse {
  data: Site[];
  pageNumber: number;
  pageSize: number;
  totalPages: number;
  totalCount: number;
  hasPreviousPage: boolean;
  hasNextPage: boolean;
}

export default function SitesManagement() {
  const [sitesData, setSitesData] = useState<PaginatedResponse>({
    data: [],
    pageNumber: 1,
    pageSize: 25,
    totalPages: 0,
    totalCount: 0,
    hasPreviousPage: false,
    hasNextPage: false
  });
  const [isLoading, setIsLoading] = useState(true);
  const [isModalOpen, setIsModalOpen] = useState(false);
  const [isDeleteModalOpen, setIsDeleteModalOpen] = useState(false);
  const [currentSite, setCurrentSite] = useState<Site | null>(null);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    fetchSites();
  }, []);

  const fetchSites = async () => {
    setIsLoading(true);
    try {
      const response = await fetch('/api/sites');
      if (!response.ok) throw new Error('Erreur lors du chargement des sites');
      const data: PaginatedResponse = await response.json();
      setSitesData(data);
    } catch (error) {
      setError('Impossible de charger les sites. Veuillez réessayer.');
      console.error(error);
    } finally {
      setIsLoading(false);
    }
  };

  const handleOpenModal = (site: Site | null = null) => {
    setCurrentSite(site);
    setIsModalOpen(true);
  };

  const handleCloseModal = () => {
    setIsModalOpen(false);
    setCurrentSite(null);
  };

  const handleOpenDeleteModal = (site: Site) => {
    setCurrentSite(site);
    setIsDeleteModalOpen(true);
  };

  const handleCloseDeleteModal = () => {
    setIsDeleteModalOpen(false);
    setCurrentSite(null);
  };

  const handleSaveSite = async (site: { ville: string }) => {
    try {
      if (currentSite) {
        const response = await fetch('/api/sites', {
          method: 'PUT',
          headers: { 'Content-Type': 'application/json' },
          body: JSON.stringify({
            id: currentSite.id,
            ville: site.ville
          }),
        });
        
        if (!response.ok) throw new Error("Erreur lors de la mise à jour");
      } else {
        const response = await fetch('/api/sites', {
          method: 'POST',
          headers: { 'Content-Type': 'application/json' },
          body: JSON.stringify(site),
        });
        
        if (!response.ok) throw new Error("Erreur lors de la création");
      }
      
      handleCloseModal();
      fetchSites();
    } catch (error) {
      console.error('Erreur lors de l\'enregistrement :', error);
      setError('Erreur lors de l\'enregistrement du site');
    }
  };

  const handleDeleteSite = async () => {
    if (!currentSite) return;
    
    try {
      const response = await fetch('/api/sites/delete', {
        method: 'POST',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify({ id: currentSite.id })
      });
      
      
      if (!response.ok) throw new Error("Erreur lors de la suppression");
      
      handleCloseDeleteModal();
      fetchSites();
    } catch (error) {
      console.error('Erreur lors de la suppression :', error);
      setError('Erreur lors de la suppression du site');
    }
  };

  return (
    <ProtectedRoute>
      <div className="container mx-auto px-4 py-8">
        <div className="flex justify-between items-center mb-6">
          <h1 className="text-2xl font-bold">Gestion des Sites</h1>
          <button
            onClick={() => handleOpenModal()}
            className="flex items-center gap-2 px-4 py-2 bg-primary text-white rounded-md hover:bg-primary-dark transition-colors"
          >
            <PlusCircle size={18} />
            <span>Ajouter un site</span>
          </button>
        </div>

        {error && (
          <div className="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded mb-4">
            {error}
          </div>
        )}

        {isLoading ? (
          <div className="flex justify-center p-8">
            <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-primary"></div>
          </div>
        ) : (
          <div className="bg-card rounded-lg border border-border shadow-sm overflow-x-auto">
            <table className="w-full">
              <thead className="bg-muted">
                <tr>
                  <th className="px-6 py-3 text-left text-sm font-medium">Site</th>
                  <th className="px-6 py-3 text-right text-sm font-medium w-24">Actions</th>
                </tr>
              </thead>
              <tbody className="divide-y divide-border">
                {sitesData.data.length === 0 ? (
                  <tr>
                    <td colSpan={2} className="px-6 py-4 text-center text-muted-foreground">
                      Aucun site trouvé
                    </td>
                  </tr>
                ) : (
                  sitesData.data.map((site) => (
                    <tr key={site.id} className="hover:bg-muted/50">
                      <td className="px-6 py-4">{site.ville}</td>
                      <td className="px-6 py-4 text-right">
                        <div className="flex justify-end gap-2">
                          <button
                            onClick={() => handleOpenModal(site)}
                            className="text-blue-600 hover:text-blue-800"
                            aria-label="Modifier"
                          >
                            <Edit size={18} />
                          </button>
                          <button
                            onClick={() => handleOpenDeleteModal(site)}
                            className="text-red-600 hover:text-red-800"
                            aria-label="Supprimer"
                          >
                            <Trash2 size={18} />
                          </button>
                        </div>
                      </td>
                    </tr>
                  ))
                )}
              </tbody>
            </table>
          </div>
        )}
      </div>

      {/* modal d'ajout/modification */}
      {isModalOpen && (
        <SiteModal
          site={currentSite}
          onClose={handleCloseModal}
          onSave={handleSaveSite}
        />
      )}

      {/* modal de confirmation de suppression */}
      {isDeleteModalOpen && currentSite && (
        <DeleteConfirmation
          title="Supprimer le site"
          message={`Êtes-vous sûr de vouloir supprimer le site de ${currentSite.ville} ?`}
          onConfirm={handleDeleteSite}
          onCancel={handleCloseDeleteModal}
        />
      )}
    </ProtectedRoute>
  );
}