import { NextRequest, NextResponse } from 'next/server';
import { fetchServicesFromBackend, updateServiceInBackend } from '@/app/lib/backend-api';

export async function GET(request: NextRequest) {
  try { 
    // récupération dess paramètres de pagination de l'url
    const { searchParams } = new URL(request.url);
    const pageNumber = parseInt(searchParams.get('pageNumber') || '1');
    const pageSize = parseInt(searchParams.get('pageSize') || '25');
    
    const data = await fetchServicesFromBackend(pageNumber, pageSize);
    
    return NextResponse.json(data);
  } catch (error) {
    console.error('Erreur lors de la récupération des services:', error);
    return NextResponse.json(
      { 
        data: [],
        pageNumber: 1,
        pageSize: 25,
        totalPages: 0,
        totalCount: 0,
        hasPreviousPage: false,
        hasNextPage: false
      },
      { status: 500 }
    );
  }
}

// vréation d'un service
export async function POST(request: NextRequest) {
  try {
    const token = request.cookies.get('admin_token')?.value;
    
    if (!token) {
      return NextResponse.json(
        { success: false, message: 'Non authentifié' },
        { status: 401 }
      );
    }
    

    const originalBody = await request.json();
    
    // vérification que le nom est présent
    if (!originalBody.nom) {
      return NextResponse.json(
        { success: false, message: 'Le nom du service est obligatoire' },
        { status: 400 }
      );
    }
    
    //  adapter le body pour correspondre aux attentes de l'api
    const transformedBody = {
      nom: originalBody.nom
    };

    
    const response = await fetch('http://localhost:5080/api/services', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
        'Authorization': `Bearer ${token}`,
        'Accept': '*/*'
      },
      body: JSON.stringify(transformedBody)
    });
    
    if (!response.ok) {
      const errorData = await response.json();
      return NextResponse.json(
        { success: false, message: errorData.message || 'Erreur lors de la création' },
        { status: response.status }
      );
    }
    
    const data = await response.json();
    return NextResponse.json(data, { status: 201 });
  } catch (error) {
    console.error('Erreur lors de la création du service:', error);
    return NextResponse.json(
      { success: false, message: 'Erreur serveur', error: String(error) },
      { status: 500 }
    );
  }
}

// mise à jour d'un service
export async function PUT(request: NextRequest) {
  try {
    const token = request.cookies.get('admin_token')?.value;
    
    if (!token) {
      return NextResponse.json(
        { success: false, message: 'Non authentifié' },
        { status: 401 }
      );
    }
    
    const originalBody = await request.json();
    
    // vérification des champs requis
    if (!originalBody.id) {
      return NextResponse.json(
        { success: false, message:`ID manquant` },
        { status: 400 }
      );
    }
    
    if (!originalBody.nom) {
      return NextResponse.json(
        { success: false, message: `Le nom est obligatoire` },
        { status: 400 }
      );
    }
    
    const data = await updateServiceInBackend(token, originalBody.id, originalBody.nom);
    
    return NextResponse.json({ success: true, data });
  } catch (error) {
    console.error('Erreur lors de la mise à jour du service : ', error);
    return NextResponse.json(
      { success: false, message: 'Erreur serveur', error: String(error) },
      { status: 500 }
    );
  }
}
