import { Service } from '@/types/Service';
import { Site } from '@/types/Site';
import { PaginatedResponse } from '@/types/PaginatedResponse';
import { ApiPaginatedResponse } from '@/types/ApiPaginatedResponse';

// fonction utilitaire pour transformer les réponses de l'API
function transformPaginatedResponse<T>(data: ApiPaginatedResponse<T>, pageNumber: number, pageSize: number): PaginatedResponse<T> {
  return {
    data: data.data || [],
    pageNumber: data.pageNumber || pageNumber,
    pageSize: data.pageSize || pageSize,
    totalPages: data.totalPages || 1,
    totalCount: data.totalCount || data.data?.length || 0,
    hasPreviousPage: data.hasPreviousPage || pageNumber > 1,
    hasNextPage: data.hasNextPage || false
  };
}

/**
 * récupère tous les services depuis le backend (sans authentification)
 */
export async function fetchServicesFromBackend(pageNumber: number, pageSize: number): Promise<PaginatedResponse<Service>> {
    const headers: HeadersInit = {
      'Accept': '*/*'
    };
    
    const response = await fetch(`http://localhost:5080/api/services?pageNumber=${pageNumber}&pageSize=${pageSize}`, {
      headers
    });
    
    if (!response.ok) {
      const errorText = await response.text();
      console.error('Erreur API services:', errorText);
      throw new Error(`Erreur HTTP ${response.status}`);
    }
    
    const data = await response.json();
    return transformPaginatedResponse<Service>(data, pageNumber, pageSize);
  }

/**
 * créé un nouveau service
 */
export async function createServiceInBackend(token: string, nom: string) {
  const transformedBody = {
    Nom: nom 
  };
  
  const response = await fetch('http://localhost:5080/api/services', {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
      'Authorization': `Bearer ${token}`,
      'Accept': '*/*'
    },
    body: JSON.stringify(transformedBody)
  });
  
  if (!response.ok) {
    const errorText = await response.text();
    console.error('Erreur création service:', errorText);
    throw new Error(`Erreur HTTP ${response.status}`);
  }
  
  return await response.json();
}

/**
 * met à jour un service existant
 */
export async function updateServiceInBackend(token: string, id: number, nom: string) {
  const transformedBody = {
    id: id,
    nom: nom
  };
  
  const response = await fetch('http://localhost:5080/api/services', {
    method: 'PUT',
    headers: {
      'Content-Type': 'application/json',
      'Authorization': `Bearer ${token}`,
      'Accept': '*/*'
    },
    body: JSON.stringify(transformedBody)
  });
  
  if (!response.ok) {
    const errorText = await response.text();
    console.error('Erreur mise à jour service:', errorText);
    throw new Error(`Erreur HTTP ${response.status}`);
  }
  
  return await response.json();
}

/**
 * supprime un service
 */
export async function deleteServiceFromBackend(token: string, id: number) {
  const response = await fetch(`http://localhost:5080/api/services/${id}`, {
    method: 'DELETE',
    headers: {
      'Authorization': `Bearer ${token}`,
      'Accept': '*/*'
    }
  });
  
  if (!response.ok) {
    const errorText = await response.text();
    console.error('Erreur suppression service:', errorText);
    throw new Error(`Erreur HTTP ${response.status}`);
  }
  
  return await response.json();
}


/**
 * récupère tous les sites
 */
export async function fetchSitesFromBackend( pageNumber: number, pageSize: number): Promise<PaginatedResponse<Site>> {
    const headers: HeadersInit = {
      'Accept': '*/*'
    };
    
    const response = await fetch(`http://localhost:5080/api/sites?pageNumber=${pageNumber}&pageSize=${pageSize}`, {
      headers
    });
    
    if (!response.ok) {
      const errorText = await response.text();
      console.error('Erreur API sites:', errorText);
      throw new Error(`Erreur HTTP ${response.status}`);
    }
    
    const data = await response.json();
    return transformPaginatedResponse<Site>(data, pageNumber, pageSize);
  }

/**
 * créé un nouveau site
 */
export async function createSiteInBackend(token: string, ville: string) {
  const transformedBody = {
    Ville: ville
  };
  
  const response = await fetch('http://localhost:5080/api/sites', {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
      'Authorization': `Bearer ${token}`,
      'Accept': '*/*'
    },
    body: JSON.stringify(transformedBody)
  });
  
  if (!response.ok) {
    const errorText = await response.text();
    console.error('Erreur création site:', errorText);
    throw new Error(`Erreur HTTP ${response.status}`);
  }
  
  return await response.json();
}

/**
 * met à jour un site
 */
export async function updateSiteInBackend(token: string, id: number, ville: string) {
  const transformedBody = {
    id: id,
    ville: ville
  };
  
  const response = await fetch('http://localhost:5080/api/sites', {
    method: 'PUT',
    headers: {
      'Content-Type': 'application/json',
      'Authorization': `Bearer ${token}`,
      'Accept': '*/*'
    },
    body: JSON.stringify(transformedBody)
  });
  
  if (!response.ok) {
    const errorText = await response.text();
    console.error('Erreur mise à jour site:', errorText);
    throw new Error(`Erreur HTTP ${response.status}`);
  }
  
  return await response.json();
}

/**
 * supprime un site
 */
export async function deleteSiteFromBackend(token: string, id: number) {
  const response = await fetch(`http://localhost:5080/api/sites/${id}`, {
    method: 'DELETE',
    headers: {
      'Authorization': `Bearer ${token}`,
      'Accept': '*/*'
    }
  });
  
  if (!response.ok) {
    const errorText = await response.text();
    console.error('Erreur suppression site:', errorText);
    throw new Error(`Erreur HTTP ${response.status}`);
  }
  
  return await response.json();
}