'use client';

import { useEffect, useState } from 'react';
import { useParams, useRouter } from 'next/navigation';
import SalarieCard from '@/components/SalarieCard';

interface SalarieData {
  id: number;
  nom: string;
  prenom: string;
  telephoneFixe: string;
  telephonePortable: string;
  email: string;
  service: { nom: string };
  site: { ville: string };
  fonctionOfficielle?: string;
  fonctionUsuelle?: string;
  notesParticulieres?: string;
}

export default function SalariePage() {
  const params = useParams();
  const router = useRouter();
  const id = params.id;
  
  const [salarieData, setSalarieData] = useState<SalarieData | null>(null);
  const [isLoading, setIsLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    async function fetchSalarieData() {
      setIsLoading(true);
      setError(null);
      try {
        const response = await fetch(`/api/salaries/${id}`);
        
        if (!response.ok) {
          throw new Error(`Erreur lors de la récupération du salarié (${response.status})`);
        }
        
        const responseData = await response.json();
        
        if (responseData.data) {
          let serviceInfo = { nom: 'Non spécifié' };
          if (responseData.data.idService) {
            try {
              const serviceResponse = await fetch(`/api/services/${responseData.data.idService}`);
              if (serviceResponse.ok) {
                const serviceData = await serviceResponse.json();
                if (serviceData.data && serviceData.data.nom) {
                  serviceInfo = { nom: serviceData.data.nom };
                }
              }
            } catch (err) {
              console.error('Erreur lors de la récupération du service:', err);
            }
          }
          
          // récupératiom des informations du site
          let siteInfo = { ville: 'Non spécifié' };
          if (responseData.data.idSite) {
            try {
              const siteResponse = await fetch(`/api/sites/${responseData.data.idSite}`);
              if (siteResponse.ok) {
                const siteData = await siteResponse.json();
                if (siteData.data && siteData.data.ville) {
                  siteInfo = { ville: siteData.data.ville };
                }
              }
            } catch (err) {
              console.error('Erreur lors de la récupération du site:', err);
            }
          }
          
          // formatage des données pour qu'elle coincident avec les attentes SalarieCard
          setSalarieData({
            id: responseData.data.id,
            nom: responseData.data.nom,
            prenom: responseData.data.prenom,
            telephoneFixe: responseData.data.telephoneFixe || '',
            telephonePortable: responseData.data.telephonePortable || '',
            email: responseData.data.email || '',
            service: serviceInfo,
            site: siteInfo,
            fonctionOfficielle: responseData.data.fonctionOfficielle || '',
            fonctionUsuelle: responseData.data.fonctionUsuelle || '',
            notesParticulieres: responseData.data.notesParticulieres || ''
          });
        } else {
          setSalarieData(responseData);
        }
      } catch (error) {
        console.error('Erreur lors du chargement du salarié:', error);
        setError("Impossible de charger les informations de ce salarié. Veuillez réessayer.");
      } finally {
        setIsLoading(false);
      }
    }
    
    if (id) {
      fetchSalarieData();
    }
  }, [id]);

  if (isLoading) {
    return (
      <div className="container mx-auto px-4 py-12">
        <div className="animate-pulse max-w-2xl mx-auto">
          <div className="h-8 bg-muted rounded-full w-3/4 mb-6"></div>
          <div className="h-64 bg-muted rounded-lg w-full mb-6"></div>
        </div>
      </div>
    );
  }

  if (error || !salarieData) {
    return (
      <div className="container mx-auto px-4 py-12">
        <div className="max-w-2xl mx-auto bg-red-50 border border-red-200 rounded-lg p-8 text-center">
          <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" strokeWidth={1.5} stroke="currentColor" className="w-12 h-12 mx-auto text-red-500 mb-4">
            <path strokeLinecap="round" strokeLinejoin="round" d="M12 9v3.75m-9.303 3.376c-.866 1.5.217 3.374 1.948 3.374h14.71c1.73 0 2.813-1.874 1.948-3.374L13.949 3.378c-.866-1.5-3.032-1.5-3.898 0L2.697 16.126zM12 15.75h.007v.008H12v-.008z" />
          </svg>
          <h2 className="text-2xl font-bold text-red-700 mb-2">Erreur</h2>
          <p className="text-red-600 mb-6">{error || "Salarié non trouvé"}</p>
          <button 
            onClick={() => router.back()} 
            className="button button-outline mx-auto"
          >
            Retour
          </button>
        </div>
      </div>
    );
  }

  return (
    <div className="container mx-auto px-4 py-12">
      
      <div className="max-w-2xl mx-auto">
        <SalarieCard salarie={salarieData} detailed={true} />
    
        <div className="mt-8 flex justify-center">
          <button 
            onClick={() => router.back()} 
            className="button button-outline"
          >
            <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" strokeWidth={1.5} stroke="currentColor" className="w-5 h-5 mr-1">
              <path strokeLinecap="round" strokeLinejoin="round" d="M10.5 19.5L3 12m0 0l7.5-7.5M3 12h18" />
            </svg>
            Retour
          </button>
        </div>
      </div>
    </div>
  );
}