'use client';

import { createContext, useContext, ReactNode, useState, useEffect } from 'react';
import { useRouter } from 'next/navigation';

interface User {
  id: number;
  email: string;
  nom: string;
  roleNom: string | null;
}

interface AuthContextType {
  user: User | null;
  login: (userData: User) => void;
  logout: () => void;
  isLoading: boolean;
}

// création du contexte
const AuthContext = createContext<AuthContextType | undefined>(undefined);

export function AuthProvider({ children }: { children: ReactNode }) {
  const [user, setUser] = useState<User | null>(null);
  const [isLoading, setIsLoading] = useState(true);
  const router = useRouter();

  // vérification de l'authentification au chargement
  useEffect(() => {
    const checkAuth = async () => {
      try {
        // appel qui permet de vérifier la session 
        const response = await fetch('/api/admin/me');
        
        console.log('Réponse status /api/admin/me:', response.status);
        
        if (response.ok) {
          const data = await response.json();
          setUser(data.user);
        } else {
          setUser(null);
        }
      } catch (error) {
        console.error(`Erreur pendant la vérification de la session`, error);
        setUser(null);
      } finally {
        setIsLoading(false);
      }
    };

    checkAuth();
  }, []);

  // fonctyion de connexion
  const handleLogin = (userData: User) => {
    setUser(userData);
  };

  // fonction de déconnexion
  const handleLogout = async () => {
    try {
      await fetch('/api/admin/logout', { method: 'POST' });
      setUser(null);
      router.push('/');
    } catch (error) {
      console.error('Erreur pendant la déconnexion:', error);
    }
  };

  return (
    <AuthContext.Provider 
      value={{ 
        user, 
        login: handleLogin, 
        logout: handleLogout, 
        isLoading 
      }}
    >
      {children}
    </AuthContext.Provider>
  );
}

// hook pour utiliser ce contexte
export function useAuth() {
  const context = useContext(AuthContext);
  if (context === undefined) {
    throw new Error(`useAuth doit-être utilisé dans l'AuthProvider`);
  }
  return context;
}