'use client'

import { useEffect, useRef } from 'react';
import Link from 'next/link';

interface MobileMenuProps {
  isOpen: boolean;
  onClose: () => void;
  isAdmin?: boolean;
  onLogout?: () => void;
}

//  affiche d'un menu pour mobile avec un bouton hamburger
const MobileMenu = ({ isOpen, onClose, isAdmin = false, onLogout }: MobileMenuProps) => {
  const menuRef = useRef<HTMLDivElement>(null);

  // gestion de la fermeture avec la touche echap
  useEffect(() => {
    const handleEscape = (e: KeyboardEvent) => {
      if (e.key === 'Escape') {
        onClose();
      }
    };

    if (isOpen) {
      document.addEventListener('keydown', handleEscape);
      // empêche le scroll
      document.body.style.overflow = 'hidden';
    }

    return () => {
      document.removeEventListener('keydown', handleEscape);
      // permet à nouveau de scroll
      document.body.style.overflow = '';
    };
  }, [isOpen, onClose]);

  if (!isOpen) return null;

  return (
    <div className="fixed inset-0 z-50 bg-background/80 backdrop-blur-sm">
      <div
        ref={menuRef}
        className={`fixed inset-y-0 right-0 w-full max-w-xs ${isAdmin ? 'bg-primary/5' : 'bg-card'} shadow-xl animate-in slide-in-from-right-full`}
      >
        <div className="flex flex-col h-full p-6">
          <div className="flex items-center justify-between mb-8">
            <h2 className="text-xl font-bold bg-gradient-to-r from-primary to-accent bg-clip-text text-transparent flex items-center">
              Annuaire CESI
              {isAdmin && (
                <span className="ml-2 text-xs px-2 py-1 bg-primary text-white rounded-md">
                  ADMIN
                </span>
              )}
            </h2>
            <button 
              onClick={onClose}
              className="p-2 rounded-full hover:bg-muted transition-colors"
            >
              <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" strokeWidth={1.5} stroke="currentColor" className="w-6 h-6">
                <path strokeLinecap="round" strokeLinejoin="round" d="M6 18L18 6M6 6l12 12" />
              </svg>
            </button>
          </div>

          <nav className="flex flex-col space-y-6">
            {isAdmin ? (
              // liens admin
              <>
                <Link href="/admin/dashboard" onClick={onClose} className="py-2 text-lg font-medium border-b border-border hover:text-primary transition-colors">
                  Dashboard
                </Link>
                <Link href="/admin/salaries" onClick={onClose} className="py-2 text-lg font-medium border-b border-border hover:text-primary transition-colors">
                  Gestion des Salariés
                </Link>
                <Link href="/admin/services" onClick={onClose} className="py-2 text-lg font-medium border-b border-border hover:text-primary transition-colors">
                  Gestion des Services
                </Link>
                <Link href="/admin/sites" onClick={onClose} className="py-2 text-lg font-medium border-b border-border hover:text-primary transition-colors">
                  Gestion des Sites
                </Link>
                {onLogout && (
                  <button 
                    onClick={() => {
                      onLogout();
                      onClose();
                    }}
                    className="py-2 text-lg font-medium text-red-600 hover:text-red-800 transition-colors"
                  >
                    Déconnexion
                  </button>
                )}
              </>
            ) : (
              // liens visiteur
              <>
                <Link href="/" onClick={onClose} className="py-2 text-lg font-medium border-b border-border hover:text-primary transition-colors">
                  Accueil
                </Link>
              </>
            )}
          </nav>

          <div className="mt-auto pt-6 border-t border-border">
            <p className="text-sm text-muted-foreground">
              &copy; {new Date().getFullYear()} Annuaire CESI.
            </p>
          </div>
        </div>
      </div>
    </div>
  );
};

export default MobileMenu;