import Link from 'next/link';
import { useState } from 'react';

interface SalarieCardProps {
  salarie: {
    id: number;
    nom: string;
    prenom: string;
    telephoneFixe: string;
    telephonePortable: string;
    email: string;
    service: { nom: string };
    site: { ville: string };
  };
  detailed?: boolean;
}

// composant qui affiche les informations du salarié, si detailed à true. il affichera l'adresse email en plus de toutes les informations de base (site, service, num portable, num fixe)
const SalarieCard: React.FC<SalarieCardProps> = ({ salarie, detailed = false }) => {
  const [isHovered, setIsHovered] = useState(false);
  
  return (
    <div 
      className={`card p-6 group ${detailed ? 'h-full' : ''}`}
      onMouseEnter={() => setIsHovered(true)}
      onMouseLeave={() => setIsHovered(false)}
    >
      <div className="flex items-start justify-between mb-4">
        <div className="flex-1">
          {!detailed ? (
            <Link href={`/salarie/${salarie.id}`}>
              <h2 className="text-xl font-bold group-hover:text-primary transition-colors">
                {salarie.prenom} {salarie.nom}
              </h2>
            </Link>
          ) : (
            <h2 className="text-xl font-bold">
              {salarie.prenom} {salarie.nom}
            </h2>
          )}
          <p className="text-sm text-muted-foreground mt-1"> <i>Service</i> : {salarie.service?.nom || 'Non spécifié'}</p>
          <p className="text-sm text-muted-foreground"> <i>Site</i> : {salarie.site?.ville || 'Non spécifié'}</p>
        </div>
        <div className={`h-16 w-16 rounded-full bg-primary/10 text-primary flex items-center justify-center text-xl font-bold transition-transform duration-300 ${isHovered ? 'scale-110' : ''}`}>
          {salarie.prenom?.[0] || '?'}{salarie.nom?.[0] || '?'}
        </div>
      </div>
      
      <div className="space-y-3 mb-4">
        {salarie.email && detailed &&(
          <div className="flex items-center text-sm">
            <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" strokeWidth={1.5} stroke="currentColor" className="w-4 h-4 mr-2 text-muted-foreground">
              <path strokeLinecap="round" strokeLinejoin="round" d="M21.75 6.75v10.5a2.25 2.25 0 01-2.25 2.25h-15a2.25 2.25 0 01-2.25-2.25V6.75m19.5 0A2.25 2.25 0 0019.5 4.5h-15a2.25 2.25 0 00-2.25 2.25m19.5 0v.243a2.25 2.25 0 01-1.07 1.916l-7.5 4.615a2.25 2.25 0 01-2.36 0L3.32 8.91a2.25 2.25 0 01-1.07-1.916V6.75" />
            </svg>
            <a href={`mailto:${salarie.email}`} className="hover:text-primary transition-colors">
              {salarie.email}
            </a>
          </div>
        )}
        
        {salarie.telephoneFixe && (
          <div className="flex items-center text-sm">
            <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" strokeWidth={1.5} stroke="currentColor" className="w-4 h-4 mr-2 text-muted-foreground">
              <path strokeLinecap="round" strokeLinejoin="round" d="M2.25 6.75c0 8.284 6.716 15 15 15h2.25a2.25 2.25 0 002.25-2.25v-1.372c0-.516-.351-.966-.852-1.091l-4.423-1.106c-.44-.11-.902.055-1.173.417l-.97 1.293c-.282.376-.769.542-1.21.38a12.035 12.035 0 01-7.143-7.143c-.162-.441.004-.928.38-1.21l1.293-.97c.363-.271.527-.734.417-1.173L6.963 3.102a1.125 1.125 0 00-1.091-.852H4.5A2.25 2.25 0 002.25 4.5v2.25z" />
            </svg>
            <a href={`tel:${salarie.telephoneFixe}`} className="hover:text-primary transition-colors">
              {salarie.telephoneFixe}
            </a>
          </div>
        )}
        
        {salarie.telephonePortable && (
          <div className="flex items-center text-sm">
            <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" strokeWidth={1.5} stroke="currentColor" className="w-4 h-4 mr-2 text-muted-foreground">
              <path strokeLinecap="round" strokeLinejoin="round" d="M10.5 1.5H8.25A2.25 2.25 0 006 3.75v16.5a2.25 2.25 0 002.25 2.25h7.5A2.25 2.25 0 0018 20.25V3.75a2.25 2.25 0 00-2.25-2.25H13.5m-3 0V3h3V1.5m-3 0h3m-3 18.75h3" />
            </svg>
            <a href={`tel:${salarie.telephonePortable}`} className="hover:text-primary transition-colors">
              {salarie.telephonePortable}
            </a>
          </div>
        )}
      </div>
      
      {!detailed && (
        <div className="pt-4 border-t border-border mt-auto">
          <Link href={`/salarie/${salarie.id}`} 
            className="flex items-center text-sm font-medium text-primary hover:text-primary-dark transition-colors"
          >
            <span>Voir le profil</span>
            <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" strokeWidth={1.5} stroke="currentColor" className="w-4 h-4 ml-1 group-hover:translate-x-1 transition-transform">
              <path strokeLinecap="round" strokeLinejoin="round" d="M13.5 4.5L21 12m0 0l-7.5 7.5M21 12H3" />
            </svg>
          </Link>
        </div>
      )}
    </div>
  );
};

export default SalarieCard;