'use client';

import { useState, useEffect } from 'react';
import { X } from 'lucide-react';
import { Site } from '@/types/Site';
import { Service } from '@/types/Service';

interface Salarie {
  id: number;
  nom: string;
  prenom: string;
  telephoneFixe: string;
  telephonePortable: string;
  email: string;
  siteId: number;
  serviceId: number;
  service: { id:number, nom: string };
  site: { id: number, ville: string };
}

interface SalarieModalProps {
  salarie: Salarie | null;
  sites: Site[];
  services: Service[];
  onClose: () => void;
  onSave: (salarie: Omit<Salarie, 'id'>) => void;
}

export default function SalarieModal({ 
  salarie, 
  sites, 
  services, 
  onClose, 
  onSave 
}: SalarieModalProps) {
  const [formData, setFormData] = useState({
    nom: '',
    prenom: '',
    telephoneFixe: '',
    telephonePortable: '',
    email: '',
    serviceId: 0,
    siteId: 0
  });
  const [errors, setErrors] = useState<{[key: string]: string}>({});

  useEffect(() => {
    if (salarie) {
      const serviceId = salarie.service?.id || 0;
      const siteId = salarie.site?.id || 0;
      
      setFormData({
        nom: salarie.nom || '',
        prenom: salarie.prenom || '',
        telephoneFixe: salarie.telephoneFixe || '',
        telephonePortable: salarie.telephonePortable || '',
        email: salarie.email || '',
        serviceId: Number(serviceId),
        siteId: Number(siteId)
      });
      
    } else if (sites.length > 0 && services.length > 0) {
      // valeur par défaut pour un nouveau salarié
      setFormData(prev => ({
        ...prev,
        serviceId: services[0].id,
        siteId: sites[0].id
      }));
    }
  }, [salarie, sites, services]);

  const handleChange = (e: React.ChangeEvent<HTMLInputElement | HTMLSelectElement>) => {
    const { name, value } = e.target;
    
    setFormData(prev => ({
      ...prev,
      [name]: name === 'serviceId' || name === 'siteId' ? parseInt(value) : value
    }));
    
    // réinitialisation de l'erreur
    if (errors[name]) {
      setErrors(prev => {
        const newErrors = {...prev};
        delete newErrors[name];
        return newErrors;
      });
    }
  };

  // fonction de validation pour les numéros de téléphone portable français :06 ou 07 (10 chiffres qui commencet par 06 ou 07)
  const validateMobileNumber = (phone: string) => {
    if (!phone) return true;
    
    const cleaned = phone.replace(/\D/g, '');
    const frenchPattern = /^0[67][0-9]{8}$/;
    
    // format international: +336 ou +337
    const internationalPattern = /^\+33[67][0-9]{8}$/;
    
    return frenchPattern.test(cleaned) || internationalPattern.test(phone);
  };

  // validation pour les numéros de téléphone fixe français 01, jusque 05 et de 08 à 09
  const validateFixedNumber = (phone: string) => {
    if (!phone) return true;
  
    const cleaned = phone.replace(/\D/g, '');
    
    const frenchPattern = /^0[1-589][0-9]{8}$/;
    
    // format international: +331, +332..
    const internationalPattern = /^\+33[1-589][0-9]{8}$/;
    
    return frenchPattern.test(cleaned) || internationalPattern.test(phone);
  };

  const validateForm = () => {
    const newErrors: {[key: string]: string} = {};
    
    if (!formData.nom.trim()) {
      newErrors.nom = "Le nom est obligatoire";
    }
    
    if (!formData.prenom.trim()) {
      newErrors.prenom = "Le prénom est obligatoire";
    }
    if (!formData.email.trim()) {
      newErrors.email = "L'email est obligatoire";
    } else if (!/\S+@\S+\.\S+/.test(formData.email)) {
      newErrors.email = "le format de l'email saisit est invalide";
    }
    
    if (formData.telephoneFixe && !validateFixedNumber(formData.telephoneFixe)) {
      newErrors.telephoneFixe = "Format de téléphone fixe invalide. Entrer un numéro à 10 chiffres commençant par 01 à 05 ou de 08 à 09";
    }
    
    if (formData.telephonePortable && !validateMobileNumber(formData.telephonePortable)) {
      newErrors.telephonePortable = "Format de téléphone portable invalide. Entrer un numéro à 10 : 06XXXXXXXX ou 07XXXXXXXX";
    }    
    if (!formData.siteId) {
      newErrors.siteId = "Le site est obligatoire";
    }
    if (!formData.serviceId) {
      newErrors.serviceId = "Le service est obligatoire";
    }
    
    
    setErrors(newErrors);
    return Object.keys(newErrors).length === 0;
  };

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
  
    if (validateForm()) {
      const selectedService = services.find(service => service.id === formData.serviceId);
      const selectedSite = sites.find(site => site.id === formData.siteId);
  
      if (!selectedService || !selectedSite) {
        console.error("Service ou site non trouvé");
        return;
      }

      const salarieData: Omit<Salarie, "id"> = {
        nom: formData.nom,
        prenom: formData.prenom,
        telephoneFixe: formData.telephoneFixe,
        telephonePortable: formData.telephonePortable,
        email: formData.email,
        serviceId: formData.serviceId,
        siteId: formData.siteId,
        service: selectedService,
        site: selectedSite,
      };
      
      onSave(salarieData);
    }
  };

  return (
    <div className="fixed inset-0 z-50 bg-black/50 flex items-center justify-center p-4 overflow-y-auto">
      <div className="bg-card rounded-lg shadow-lg max-w-2xl w-full overflow-hidden  backdrop-blur-md">
        <div className="flex justify-between items-center px-6 py-4 border-b border-border">
          <h2 className="text-xl font-semibold">
            {salarie ? 'Modifier le salarié' : 'Ajouter un salarié'}
          </h2>
          <button 
            onClick={onClose}
            className="text-muted-foreground hover:text-foreground"
          >
            <X size={24} />
          </button>
        </div>
        
        <form onSubmit={handleSubmit} className="p-6">
          <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
            {/* nom */}
            <div>
              <label htmlFor="nom" className="block text-sm font-medium mb-2">
                Nom <span className="text-red-500">*</span>
              </label>
              <input
                type="text"
                id="nom"
                name="nom"
                value={formData.nom}
                onChange={handleChange}
                className={`w-full px-3 py-2 border ${errors.nom ? 'border-red-500' : 'border-border'} rounded-md focus:outline-none focus:ring-2 focus:ring-primary`}
              />
              {errors.nom && <p className="mt-1 text-sm text-red-500">{errors.nom}</p>}
            </div>
            
            {/* prénom */}
            <div>
              <label htmlFor="prenom" className="block text-sm font-medium mb-2">
                Prénom <span className="text-red-500">*</span>
              </label>
              <input
                type="text"
                id="prenom"
                name="prenom"
                value={formData.prenom}
                onChange={handleChange}
                className={`w-full px-3 py-2 border ${errors.prenom ? 'border-red-500' : 'border-border'} rounded-md focus:outline-none focus:ring-2 focus:ring-primary`}
              />
              {errors.prenom && <p className="mt-1 text-sm text-red-500">{errors.prenom}</p>}
            </div>
            
            {/* email */}
            <div>
              <label htmlFor="email" className="block text-sm font-medium mb-2">
                Email <span className="text-red-500">*</span>
              </label>
              <input
                type="email"
                id="email"
                name="email"
                value={formData.email}
                onChange={handleChange}
                className={`w-full px-3 py-2 border ${errors.email ? 'border-red-500' : 'border-border'} rounded-md focus:outline-none focus:ring-2 focus:ring-primary`}
              />
              {errors.email && <p className="mt-1 text-sm text-red-500">{errors.email}</p>}
            </div>
            
            {/* fixe */}
            <div>
              <label htmlFor="telephoneFixe" className="block text-sm font-medium mb-2">
                Téléphone Fixe
              </label>
              <input
                type="tel"
                id="telephoneFixe"
                name="telephoneFixe"
                value={formData.telephoneFixe}
                onChange={handleChange}
                placeholder="0123456789"
                className={`w-full px-3 py-2 border ${errors.telephoneFixe ? 'border-red-500' : 'border-border'} rounded-md focus:outline-none focus:ring-2 focus:ring-primary`}
              />
              {errors.telephoneFixe && <p className="mt-1 text-sm text-red-500">{errors.telephoneFixe}</p>}
            </div>
            
            {/* portable */}
            <div>
              <label htmlFor="telephonePortable" className="block text-sm font-medium mb-2">
                Téléphone Portable
              </label>
              <input
                type="tel"
                id="telephonePortable"
                name="telephonePortable"
                value={formData.telephonePortable}
                onChange={handleChange}
                placeholder="0612345678"
                className={`w-full px-3 py-2 border ${errors.telephonePortable ? 'border-red-500' : 'border-border'} rounded-md focus:outline-none focus:ring-2 focus:ring-primary`}
              />
              {errors.telephonePortable && <p className="mt-1 text-sm text-red-500">{errors.telephonePortable}</p>}
            </div>
            
            {/* service */}
            <div>
              <label htmlFor="serviceId" className="block text-sm font-medium mb-2">
                Service <span className="text-red-500">*</span>
              </label>
              <select
                id="serviceId"
                name="serviceId"
                value={String(formData.serviceId)}
                onChange={handleChange}
                className={`w-full px-3 py-2 border ${errors.serviceId ? 'border-red-500' : 'border-border'} rounded-md focus:outline-none focus:ring-2 focus:ring-primary`}
              >
                <option value="">Sélectionner un service</option>
                {services.map((service) => (
                  <option key={service.id} value={String(service.id)}>{service.nom}</option>
                ))}
              </select>
              {errors.serviceId && <p className="mt-1 text-sm text-red-500">{errors.serviceId}</p>}
            </div>
            
            {/* site */}
            <div>
              <label htmlFor="siteId" className="block text-sm font-medium mb-2">
                Site <span className="text-red-500">*</span>
              </label>
              <select
                id="siteId"
                name="siteId"
                value={String(formData.siteId)}
                onChange={handleChange}
                className={`w-full px-3 py-2 border ${errors.siteId ? 'border-red-500' : 'border-border'} rounded-md focus:outline-none focus:ring-2 focus:ring-primary`}
              >
                <option value="">Sélectionner un site</option>
                {sites.map((site) => (
                  <option key={site.id} value={String(site.id)}>{site.ville}</option>
                ))}
              </select>
              {errors.siteId && <p className="mt-1 text-sm text-red-500">{errors.siteId}</p>}
            </div>
          </div>
          
          <div className="flex justify-end gap-3 mt-6">
            <button
              type="button"
              onClick={onClose}
              className="px-4 py-2 border border-border rounded-md hover:bg-muted transition-colors"
            >
              Annuler
            </button>
            <button
              type="submit"
              className="px-4 py-2 bg-primary text-white rounded-md hover:bg-primary-dark transition-colors"
            >
              Enregistrer
            </button>
          </div>
        </form>
      </div>
    </div>
  );
}